import router from './router'
import store from './store'
import { Message } from 'element-ui'
import NProgress from 'nprogress' // progress bar
import 'nprogress/nprogress.css' // progress bar style
import { getToken } from '@/utils/auth' // get token from cookie
import getPageTitle from '@/utils/get-page-title'

import { filterRouter } from '@/filterRouter'

NProgress.configure({ showSpinner: false }) // 滚动条配置

const whiteList = ['/login', '/auth-redirect', '/1', '/2'] // 路由重定向白名单

router.beforeEach(async(to, from, next) => {
  // 开始加载滚动条
  NProgress.start()

  // 设置title
  document.title = getPageTitle(to.meta.title)

  // 确定用户是否已登录
  const hasToken = getToken()

  if (hasToken) {
    if (to.path === '/login') {
      // 如果重新登录跳转到首页
      next({ path: '/' })
      NProgress.done()
    } else {
      // 确定用户是否已通过getInfo获得其路由信息
      const hasRoutes = store.getters.permission_routes && store.getters.permission_routes.length > 0
      if (hasRoutes) {
        next()
      } else {
        try {
          // 获取用户拥有的路由信息
          const { routes } = await store.dispatch('user/getInfo')
          // 根据获得账户路由生成路由树
          let accessRoutes
          try {
            accessRoutes = filterRouter(routes)
          } catch (e) {
            console.log(e + '11111111111')
            await store.dispatch('user/resetToken')
            Message.error('路由错误')
            next(`/login?redirect=${to.path}`)
            NProgress.done()
            return false
          }
          // 动态添加可访问路由
          router.addRoutes(accessRoutes)
          next({ ...to, replace: true })
        } catch (error) {
          console.log(error)
          // 重新登录
          await store.dispatch('user/resetToken')
          Message.error(error || 'Has Error')
          next(`/login?redirect=${to.path}`)
          NProgress.done()
        }
      }
    }
  } else {
    /* 不存在token */
    if (whiteList.indexOf(to.path) !== -1) {
      // 在免费登录白名单中，直接进入
      next()
    } else {
      // 没有访问权限的其他页将重定向到登录页。
      // next(`/login?redirect=${to.path}`)
      next(`/login`)
      NProgress.done()
    }
  }
})

router.afterEach(() => {
  // 导航条结束加载
  NProgress.done()
})
